==> igniteui-react-16.16.2.tgz: package/esm2015/lib/Icon.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
/**
 * @hidden
 */
export let Icon = /*@__PURE__*/ (() => {
    class Icon extends BaseElement {
        constructor() {
            super(...arguments);
            this.b = new WCNativeHelper();
            this.e = null;
        }
        get c() {
            return this.b;
        }
        get nativeElement() {
            return this.e;
        }
        set nativeElement(a) {
            this.e = a;
            this.b.d = this.e;
        }
        get h() {
            let ret_ = this.c.c("name");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.c.i("name", value_);
        }
        get g() {
            let ret_ = this.c.c("collection");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.c.i("collection", value_);
        }
        get d() {
            let ret_ = this.c.c("mirrored");
            return ret_;
        }
        set d(a) {
            let value_ = a;
            this.c.i("mirrored", value_);
        }
        get a() {
            let ret_ = this.c.c("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, EnumUtil.parse(SizableComponentSize_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.c.i("size", value_);
        }
        i() {
            this.nativeElement.connectedCallback();
        }
        j() {
            this.nativeElement.disconnectedCallback();
        }
        k(a, b, c) {
            this.nativeElement.registerIcon(a, b, c);
        }
        l(a, b, c) {
            this.nativeElement.registerIconFromText(a, b, c);
        }
    }
    Icon.$t = /*@__PURE__*/ markType(Icon, 'Icon', BaseElement.$);
    return Icon;
})();

==> igniteui-react-18.5.1.tgz: package/esm2015/lib/Icon.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
/**
 * @hidden
 */
export let Icon = /*@__PURE__*/ (() => {
    class Icon extends BaseElement {
        constructor() {
            super(...arguments);
            this.b = new WCNativeHelper();
            this.e = null;
        }
        get c() {
            return this.b;
        }
        get nativeElement() {
            return this.e;
        }
        set nativeElement(a) {
            this.e = a;
            this.b.o = this.e;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get h() {
            let ret_ = this.c.n("name");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.c.v("name", value_);
        }
        get g() {
            let ret_ = this.c.n("collection");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.c.v("collection", value_);
        }
        get d() {
            let ret_ = this.c.n("mirrored");
            return ret_;
        }
        set d(a) {
            let value_ = a;
            this.c.v("mirrored", value_);
        }
        get a() {
            let ret_ = this.c.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.c.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.c.v("size", value_);
        }
        i() {
            this.nativeElement.connectedCallback();
        }
        j() {
            this.nativeElement.disconnectedCallback();
        }
        k(a, b, c) {
            this.nativeElement.registerIcon(this.c.i(a), this.c.i(b), this.c.i(c));
        }
        l(a, b, c) {
            this.nativeElement.registerIconFromText(this.c.i(a), this.c.i(b), this.c.i(c));
        }
    }
    Icon.$t = /*@__PURE__*/ markType(Icon, 'Icon', BaseElement.$);
    return Icon;
})();
